/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package queues;

import java.util.Collections;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Pull;
import org.objectweb.dream.control.activity.Util;
import org.objectweb.dream.control.activity.task.AbstractTask;
import org.objectweb.dream.control.activity.task.Task;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.dream.queue.SequenceNumberChunk;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * This component has a task that periodically pulls a message on its Pull
 * input.
 */
public class PullGeneratorImpl extends AbstractComponent
{

  Pull           inPullItf;
  MessageManager messageManagerItf;

  Task           tasks;

  // -------------------------------------------------------------------------
  // Overriden methods
  // -------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.AbstractComponent#beforeFirstStart(org.objectweb.fractal.api.Component)
   */
  protected void beforeFirstStart(Component componentItf)
      throws IllegalLifeCycleException
  {
    try
    {
      Util.addTask(componentItf, new GeneratorTask("Pull generator task1"),
          Collections.EMPTY_MAP);
      Util.addTask(componentItf, new GeneratorTask("Pull generator task2"),
          Collections.EMPTY_MAP);
      logger.log(BasicLevel.DEBUG, "tasks added");
    }
    catch (Exception e)
    {
      throw new IllegalLifeCycleException("Can't add task");
    }
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(Pull.IN_PULL_ITF_NAME))
    {
      inPullItf = (Pull) serverItf;
    }
    else if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{Pull.IN_PULL_ITF_NAME, MessageManager.ITF_NAME};
  }

  // ---------------------------------------------------------------------------
  // The task.
  // ---------------------------------------------------------------------------

  private class GeneratorTask extends AbstractTask
  {

    /**
     * Constructor
     */
    public GeneratorTask(String message)
    {
      super(message);
    }

    /**
     * @see Task#execute(Object)
     */
    public Object execute(Object hints) throws InterruptedException
    {
      try
      {
        Message msg = inPullItf.pull(null);
        if (msg == null)
        {
          logger.log(BasicLevel.INFO, "Pulled null message");
        }
        else
        {
          HelloWorldChunk chunk = (HelloWorldChunk) msg
              .getChunk(HelloWorldChunk.DEFAULT_NAME);
          SequenceNumberChunk snchunk = (SequenceNumberChunk) msg
              .getChunk(SequenceNumberChunk.DEFAULT_NAME);
          logger.log(BasicLevel.INFO, "Sequence number = "
              + snchunk.getSequenceNumber() + " msg = " + chunk.getMessage());
          messageManagerItf.deleteMessage(msg);
        }
      }
      catch (Exception e)
      {
        e.printStackTrace();
        return STOP_EXECUTING;
      }
      Thread.sleep(1000);
      return EXECUTE_AGAIN;
    }
  }
}