/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package utobcast;

import java.util.Map;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Push;
import org.objectweb.dream.PushException;
import org.objectweb.dream.channel.IPChannelDestinationChunk;
import org.objectweb.dream.message.MessageTypeImpl;
import org.objectweb.dream.message.ChunkAlreadyExistsException;
import org.objectweb.dream.message.ExtensibleMessage;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.MessageType;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.dream.protocol.utobcast.message.UTOBcastChunk;
import org.objectweb.dream.util.Error;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

import utobcast.basic.TestChunk;

/**
 * Implementation of the IPDestinationChunkTransformer component. This component
 * retrieves the IP address and port of the Process to which this message is
 * intended. It then fills an IPDestinationChunk with this information.
 * 
 * @see IPChannelDestinationChunk
 * @see org.objectweb.dream.protocol.utobcast.message.UTOBcastChunk
 * @see TCPProcess
 */
public class IPDestinationChunkTransformerImpl extends AbstractComponent
    implements
      Push
{

  Push           outPushItf;
  MessageManager messageManagerItf;
  MessageType    msgType   = new MessageTypeImpl(TestChunk.DEFAULT_NAME,
                               TestChunk.TYPE);
  final String   chunkName = "destination";

  // ---------------------------------------------------------------------------
  // Implementation of the Push interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.Push#push(org.objectweb.dream.message.Message,
   *      java.util.Map)
   */
  public void push(Message message, Map context) throws PushException
  {
    UTOBcastChunk utobcastChunk = (UTOBcastChunk) message
        .getChunk(UTOBcastChunk.DEFAULT_NAME);
    TCPProcess process = (TCPProcess) utobcastChunk.getProcessTo();
    IPChannelDestinationChunk chunk = (IPChannelDestinationChunk) message
        .getChunk(chunkName);
    if (chunk == null)
    {
      if (message instanceof ExtensibleMessage)
      {
        chunk = (IPChannelDestinationChunk) messageManagerItf
            .createChunk(IPChannelDestinationChunk.TYPE);
        try
        {
          ((ExtensibleMessage) message).addChunk(chunkName,
              IPChannelDestinationChunk.TYPE, chunk);
        }
        catch (ChunkAlreadyExistsException e)
        {
          // cannot happend
        }
      }
      else
      {
        Error.error("Invalid message : not extensible", logger);
      }
    }
    chunk.setChannelDestinationAddr(process.getInetAddress());
    chunk.setChannelDestinationPort(process.getPort());
    outPushItf.push(message, context);
  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(Push.OUT_PUSH_ITF_NAME))
    {
      outPushItf = (Push) serverItf;
    }
    else if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{Push.OUT_PUSH_ITF_NAME, MessageManager.ITF_NAME};
  }

}