/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.protocol;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;

/**
 * A basic Chunk interface that defines an arrow from a source process to a
 * destination process.
 */
public class ArrowChunkImpl extends AbstractChunk
    implements
      ArrowChunk,
      Chunk,
      Externalizable
{

  private short processFrom;
  private short processTo;

  // ---------------------------------------------------------------------------
  // Implementation of the ArrowChunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see ArrowChunk#getProcessIdFrom()
   */
  public short getProcessIdFrom()
  {
    return processFrom;
  }

  /**
   * @see ArrowChunk#setProcessIdFrom(short)
   */
  public void setProcessIdFrom(short from)
  {
    processFrom = from;
  }

  /**
   * @see ArrowChunk#getProcessIdTo()
   */
  public short getProcessIdTo()
  {
    return processTo;
  }

  /**
   * @see ArrowChunk#setProcessIdTo(short)
   */
  public void setProcessIdTo(short to)
  {
    processTo = to;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return ArrowChunk.TYPE;
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ArrowChunk newInst = (ArrowChunk) newInstance;
    newInst.setProcessIdFrom(getProcessIdFrom());
    newInst.setProcessIdTo(getProcessIdTo());
  }

  // ---------------------------------------------------------------------------
  // Implementation of the serialization methods
  // ---------------------------------------------------------------------------

  /**
   * @see Externalizable#readExternal(ObjectInput)
   */
  public void readExternal(ObjectInput in) throws IOException,
      ClassNotFoundException
  {
    processFrom = in.readShort();
    processTo = in.readShort();
  }

  /**
   * @see Externalizable#writeExternal(ObjectOutput)
   */
  public void writeExternal(ObjectOutput out) throws IOException
  {
    out.writeShort(processFrom);
    out.writeShort(processTo);
  }

}