/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.utobcast;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Push;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.dream.protocol.Process;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * Implementation of the LeaderFaultForwarder component. This component is
 * notified by the ProcessMembership component that the leader has crashed. Its
 * role is to unblock push calls that are waiting in the PushWithReturn
 * component by sending a "AllKey" message.
 */
public class LeaderFaultForwarderImpl extends AbstractComponent
    implements
      ProcessMembershipUpdateNotification
{

  // ---------------------------------------------------------------------------
  // Fields of this class
  // ---------------------------------------------------------------------------

  /** The interface to send "AllKey" messages. */
  protected Push           outPushItf;

  /** The interface to manage message lifecycle. */
  protected MessageManager messageManagerItf;

  // ---------------------------------------------------------------------------
  // Constructor
  // ---------------------------------------------------------------------------

  /**
   * Constructor.
   */
  public LeaderFaultForwarderImpl()
  {
  }

  // ---------------------------------------------------------------------------
  // Implementation of the ProcessMembershipUpdateNotification interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.protocol.utobcast.ProcessMembershipUpdateNotification#newBackup(org.objectweb.dream.protocol.Process)
   */
  public void newBackup(Process backup)
  {
    // TODO Auto-generated method stub

  }

  /**
   * @see org.objectweb.dream.protocol.utobcast.ProcessMembershipUpdateNotification#newLeader(org.objectweb.dream.protocol.Process)
   */
  public void newLeader(Process leader)
  {
    // TODO Auto-generated method stub

  }

  /**
   * @see org.objectweb.dream.protocol.utobcast.ProcessMembershipUpdateNotification#newProcesses(org.objectweb.dream.protocol.Process[])
   */
  public void newProcesses(Process[] processes)
  {
    // TODO Auto-generated method stub

  }

  // ---------------------------------------------------------------------------
  // Implementation of the BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    super.bindFc(clientItfName, serverItf);
    if (clientItfName.equals(Push.OUT_PUSH_ITF_NAME))
    {
      outPushItf = (Push) serverItf;
    }
    else if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{Push.OUT_PUSH_ITF_NAME, MessageManager.ITF_NAME};
  }

}