/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.utobcast;

import org.objectweb.dream.protocol.Process;

/**
 * This interface defines methods for being notified about ProcessMembership
 * updates.
 */
public interface ProcessMembershipUpdateNotification
{
  /** The commonly used name to refer to this interface. */
  String ITF_NAME = "process-membership-update-notification";

  /**
   * Notifies the component that a new leader has been elected.
   * 
   * @param leader the new leader.
   */
  void newLeader(Process leader);

  /**
   * Notifies the component that a new backup has been elected.
   * 
   * @param backup the new backup.
   */
  void newBackup(Process backup);

  /**
   * Notifies the component that new processes have joined.
   * 
   * @param processes the new processes.
   */
  void newProcesses(Process[] processes);
}