/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.protocol.utobcast.message;

import org.objectweb.dream.message.AbstractChunk;
import org.objectweb.dream.message.Chunk;
import org.objectweb.dream.message.ChunkType;
import org.objectweb.dream.protocol.Process;

/**
 * Basic implementation of the {@link UTOBcastChunk}interface.
 */
public class UTOBcastChunkImpl extends AbstractChunk implements UTOBcastChunk
{
  /** The type of the message that contains this chunk. */
  protected byte    utoBcastMessageType = -1;

  /** The process that sent this chunk. */
  protected Process processFrom;

  /** The process to which this chunk is destinated. */
  protected Process processTo;

  /** The sequence number of this message. */
  protected long    sn                  = -1;

  // ---------------------------------------------------------------------------
  // Implementation of the UTOBcastChunk interface
  // ---------------------------------------------------------------------------
  /**
   * @see UTOBcastChunk#getUTOBcastMessageType()
   */
  public byte getUTOBcastMessageType()
  {
    return utoBcastMessageType;
  }

  /**
   * @see UTOBcastChunk#setUTOBcastMessageType(byte)
   */
  public void setUTOBcastMessageType(byte type)
  {
    this.utoBcastMessageType = type;
  }

  /**
   * @see UTOBcastChunk#getProcessFrom()
   */
  public Process getProcessFrom()
  {
    return processFrom;
  }

  /**
   * @see UTOBcastChunk#setProcessFrom(Process)
   */
  public void setProcessFrom(Process process)
  {
    this.processFrom = process;
  }

  /**
   * @see UTOBcastChunk#getProcessTo()
   */
  public Process getProcessTo()
  {
    return processTo;
  }

  /**
   * @see UTOBcastChunk#setProcessTo(Process)
   */
  public void setProcessTo(Process process)
  {
    this.processTo = process;
  }

  /**
   * @see UTOBcastChunk#setSequenceNumber(long)
   */
  public void setSequenceNumber(long sn)
  {
    this.sn = sn;
  }

  /**
   * @see UTOBcastChunk#getSequenceNumber()
   */
  public long getSequenceNumber()
  {
    return sn;
  }

  // ---------------------------------------------------------------------------
  // Implementation of the Chunk interface
  // ---------------------------------------------------------------------------

  /**
   * @see Chunk#getType()
   */
  public ChunkType getType()
  {
    return TYPE;
  }

  /**
   * @see Chunk#transfertState(Chunk)
   */
  public void transfertState(Chunk newInstance)
  {
    ((UTOBcastChunk) newInstance)
        .setUTOBcastMessageType(getUTOBcastMessageType());
    ((UTOBcastChunk) newInstance).setSequenceNumber(getSequenceNumber());
    ((UTOBcastChunk) newInstance).setProcessFrom(getProcessFrom());
    ((UTOBcastChunk) newInstance).setProcessTo(getProcessTo());
  }

  /**
   * @see Chunk#recycle()
   */
  public void recycle()
  {
    utoBcastMessageType = -1;
    processFrom = null;
    processTo = null;
    sn = -1;
  }

}