/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.control.logger;

import org.objectweb.util.monolog.api.Level;

/**
 * Controller interface to control
 * {@link org.objectweb.util.monolog.api.Logger loggers }associated with the
 * component this controller belong. Every loggers define in a component shared
 * the same base name and have a suffix (can be <code>null</code>).
 */
public interface LoggerController
{

  /**
   * Sets the loggers' base name.
   * 
   * @param name the base name
   */
  void setBaseName(String name);

  /**
   * Returns the loggers' base name.
   * 
   * @return the loggers' base name.
   */
  String getBaseName();

  /**
   * Returns the current logging level of a logger
   * 
   * @param loggerName the name of the logger
   * @return the current logging level of a logger
   */
  Level getLoggerLevel(String loggerName);

  /**
   * Sets the logging level of a logger.
   * 
   * @param loggerName the name of the logger
   * @param level a level
   */
  void setLoggerLevel(String loggerName, Level level);

}