/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.message.codec;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.MessageNC;
import org.objectweb.dream.message.MessageTypeImpl;
import org.objectweb.dream.message.MessageTypeNCImpl;

/**
 * Basic implementation of a message codec.
 */
public class MessageCodecStreamImpl extends AbstractMessageCodecObjectStream
{

  // ---------------------------------------------------------------------------
  // Implementation of the AbstractMessageCodecDataStream abstract methods
  // ---------------------------------------------------------------------------

  /**
   * @see AbstractMessageCodecDataStream#doDecodeSingleMessage(DataInput)
   */
  protected Message doDecodeSingleMessage(DataInput input) throws IOException
  {
    Message m;
    boolean messageNC = input.readBoolean();
    if (messageNC)
    {
      m = messageManagerItf.createMessage(MessageTypeNCImpl.EMPTY_MESSAGE_TYPE_NC);
    }
    else
    {
      m = messageManagerItf.createMessage(MessageTypeImpl.EMPTY_MESSAGE_TYPE);
    }
    try
    {
      ((Externalizable) m).readExternal((ObjectInput) input);
    }
    catch (ClassNotFoundException e)
    {
      throw new IOException("Unable to decode message : " + e.getMessage());
    }
    m.setMessageManagerId(messageManagerItf.getMessageManagerId());
    return m;
  }

  /**
   * @see AbstractMessageCodecDataStream#doEncodeSingleMessage(Message,
   *      DataOutput)
   */
  protected void doEncodeSingleMessage(Message message, DataOutput output)
      throws IOException
  {
    if (message instanceof MessageNC)
    {
      output.writeBoolean(true);
    }
    else
    {
      output.writeBoolean(false);
    }
    ((Externalizable) message).writeExternal((ObjectOutput) output);
  }
}